@@ -26,18 +26,19 @@ import Data.Map (Map)
 import qualified Data.Map as Map
 import Data.Set (Set)
 import qualified Data.Set as Set
+import Data.Version
 import System.Console.GetOpt
 import System.Directory
 import System.Environment
 import System.Exit
 import System.IO
-import Text.XML.HaXml hiding (when)
+import Text.XML.HaXml hiding (when,version)
 
 import Config
 import Darcs
 import EmailPatch
 import PatchData
-import Version
+import Paths_darcs_monitor (version)
 
 data Opt = HelpOpt
          | VersionOpt
@@ -94,7 +95,8 @@ main = do args <- getArgs
                               exitWith ExitSuccess
                     where usage pn = "Usage: " ++ pn ++
                                      " [OPTIONS] email RECIPIENT [REPO ...]"
-                VersionOpt -> do putStrLn packageVersion
+                VersionOpt -> do putStrLn $ "darcs-monitor " ++
+                                            showVersion version
                                  exitWith ExitSuccess
                 _ -> return ()
           let dryRun = findOpt roa False $ \opt ->
